@@ -7,10 +7,9 @@ import random
 
 import numpy as np
 import pytest
+from pde.tools import spherical
 from scipy import integrate, spatial
 
-from .. import spherical
-
 
 def test_volume_conversion():
     """ tests conversion of volume and radius of droplet """
@@ -119,6 +118,10 @@ def test_points_on_sphere_2():
 
 def test_spherical_index():
     """ test the conversion of the spherical index """
+    # check initial state
+    assert spherical.spherical_index_lm(0) == (0, 0)
+    assert spherical.spherical_index_k(0, 0) == 0
+
     # check conversion
     for k in range(20):
         l, m = spherical.spherical_index_lm(k)
@@ -132,14 +135,14 @@ def test_spherical_index():
             k += 1
 
     for l in range(4):
-        assert (
-            spherical.spherical_index_count(l) == spherical.spherical_index_k(l, l) + 1
-        )
+        k_max = spherical.spherical_index_k(l, l)
+        assert spherical.spherical_index_count(l) == k_max + 1
 
     for l in range(4):
         for m in range(-l, l + 1):
+            is_optimal = m == l
             k = spherical.spherical_index_k(l, m)
-            assert spherical.spherical_index_count_optimal(k + 1) == (m == l)
+            assert spherical.spherical_index_count_optimal(k + 1) == is_optimal
 
 
 def test_spherical_harmonics_real():
